pro readtsys2, dir=dir, rx=rx

common global
common data_set


if not keyword_set(dir) then dir=e.idl_bcp
result = findfile(e.idl_bcp+'tsys_read',count=count)
if (count eq 0) then begin
   print,'could not find file ',e.idl_bcp+'tsys_read'
   return
endif
print,'******** OS TYPE ***********'
print,'Platform =',!VERSION.ARCH
print,'TSYS reading ...'
;print,'This TSYS reading program will work on the full dataset' 
;print,'     and ignore any data filtering....'
;
;  Set up structures for tsys header table
;
;  Assumptions: 
;  1. the correlator setup is fixed for the whole track -
;  2. tsys file contains the tsys information from antennas used in the track
distinct_iband=uti_distinct(sp.iband,nbands,/many_repeat)
distinct_irec=uti_distinct(bl.irec,nrecs,/many_repeat)
if nrecs gt 2 then begin
   print,'More than ',nrecs, ' receivers data recorded.'
   print,'Quit!'
   return
endif

openr,unit,dir+'/tsys_read',/get_lun,error=err
if err ne 0 then begin
  print,!err_string
  return
endif

nM=0L

result=dat_filter(s_f,/reset,/no_notify)
ints=bl[pbf].inhid
ii=uti_distinct(in[pif].inhid,nint,/many_repeat)

for i=0L,nint-1L do begin
   ; 1. different int might have different ants.
   ; 2. for individual int, assign tsys for available ants.
   ; 3. assume tsys are same for both sidebands.
   tmp_idx = where(ints eq ii[i], ncombo)
   ants=[bl[pbf[tmp_idx[0]]].itel1,uti_distinct(bl[pbf[tmp_idx]].itel2,/many)]
   nants=n_elements(ants)
   ibsl=where((sp[psf[tmp_idx]].iband eq 0) and bl[pbf[tmp_idx]].isb eq 0,count); ibsl: baseline index
   first_byte=bl[pbf[tmp_idx[ibsl[0]]]].ant1tsysoff
   point_lun,unit,first_byte
   readu,unit,nM
   if nM gt 2 then begin
      print,'************* More than ',nM,' TSYS measurements'
      print,'************* Need to check the routine. Quit !'
      return
   endif
   data=fltarr(4,nM)
   tsys_temp={itel:0,tssb:fltarr(nM)}
   tsys = replicate(tsys_temp,nants)
   readu,unit,data
                                ; for normal data, nM=2 (both IFs or RXs):
                                ; data[2,*] for lsb and data[3,*] for usb

   tsys[0].itel=bl[pbf[tmp_idx[ibsl[0]]]].itel1
   tsys[0].tssb=data[2,*] ; assuming data[2,*] (lsb) = data[3,*] (usb)
   for iant=1, nants-1 do begin
      first_byte=bl[pbf[tmp_idx[ibsl[iant-1]]]].ant2tsysoff
      point_lun,unit,first_byte
      readu,unit,nM
      data=fltarr(4,nM)
      readu,unit,data
      tsys[iant].itel=bl[pbf[tmp_idx[ibsl[iant-1]]]].itel2
      tsys[iant].tssb=data[2,*] ; assuming data[2,*] (lsb) = data[3,*] (usb)
   endfor

   for j=0,nants-2 do begin
      for k=j+1,nants-1 do begin
         if nrecs eq 2 then begin
            ; double rx
            loc=where(bl[pbl[tmp_idx]].itel1 eq ants[j] and bl[pbl[tmp_idx]].itel2 eq ants[k] and bl[pbl[tmp_idx]].irec eq distinct_irec[0], count)
            if count gt 0 then begin
               jj=where(tsys.itel eq ants[j])
               tmpj=tsys[jj].tssb[0]
               kk=where(tsys.itel eq ants[k])
               tmpk=tsys[kk].tssb[0]
               sp[psl[tmp_idx[loc]]].tssb=sqrt(tmpj*tmpk)
            endif           
            loc=where(bl[pbl[tmp_idx]].itel1 eq ants[j] and bl[pbl[tmp_idx]].itel2 eq ants[k] and bl[pbl[tmp_idx]].irec eq distinct_irec[1], count)
            if count gt 0 then begin
               jj=where(tsys.itel eq ants[j])
               tmpj=tsys[jj].tssb[1]
               kk=where(tsys.itel eq ants[k])
               tmpk=tsys[kk].tssb[1]
               sp[psl[tmp_idx[loc]]].tssb=sqrt(tmpj*tmpk)
            endif                       
         endif else begin
            ; rx =400
            if float(rx) eq 400 or float(rx) eq 690 then begin
               loc=where(bl[pbl[tmp_idx]].itel1 eq ants[j] and bl[pbl[tmp_idx]].itel2 eq ants[k], count)
               if count gt 0 then begin
                  jj=where(tsys.itel eq ants[j])
                  tmpj=tsys[jj].tssb[1]
                  kk=where(tsys.itel eq ants[k])
                  tmpk=tsys[kk].tssb[1]
                  sp[psl[tmp_idx[loc]]].tssb=sqrt(tmpj*tmpk)
               endif
            endif else begin
               ; single rx
               loc=where(bl[pbl[tmp_idx]].itel1 eq ants[j] and bl[pbl[tmp_idx]].itel2 eq ants[k] and sp[psl[tmp_idx]].iband le 24, count)
               if count gt 0 then begin
                  jj=where(tsys.itel eq ants[j])
                  tmpj=(tsys[jj].tssb[0] gt 0) ? tsys[jj].tssb[0]: 99999
                  kk=where(tsys.itel eq ants[k])
                  tmpk=(tsys[kk].tssb[0] gt 0) ? tsys[kk].tssb[0]: 99999 
                  sp[psl[tmp_idx[loc]]].tssb=sqrt(tmpj*tmpk)
               endif
               loc=where(bl[pbl[tmp_idx]].itel1 eq ants[j] and bl[pbl[tmp_idx]].itel2 eq ants[k] and sp[psl[tmp_idx]].iband gt 24, count)
               if count gt 0 then begin
                  jj=where(tsys.itel eq ants[j])
                  tmpj=(tsys[jj].tssb[1] gt 0) ?  tsys[jj].tssb[1]: 99999
                  kk=where(tsys.itel eq ants[k])
                  tmpk=(tsys[kk].tssb[1] gt 0) ?  tsys[kk].tssb[1]: 99999 
                  sp[psl[tmp_idx[loc]]].tssb=sqrt(tmpj*tmpk)
               endif
            endelse
         endelse
      endfor
   endfor
endfor

close,unit & free_lun,unit

print,'finished reading TSYS structure'

return
end

